Type: Package
Package: shiny.telemetry
Title: 'Shiny' App Usage Telemetry
Version: 0.3.2
Authors@R: c(
    person("André", "Veríssimo", , "opensource+andre@appsilon.com", role = c("aut", "cre")),
    person("Kamil", "Żyła", , "kamil@appsilon.com", role = "aut"),
    person("Krystian", "Igras", , "krystian8207@gmail.com", role = "aut"),
    person("Recle", "Vibal", , "recle.vibal@appsilon.com", role = "aut"),
    person("Arun", "Kodati", , "arun.kodati@appsilon.com", role = "aut"),
    person("Wahaduzzaman", "Khan", , "wahaduzzaman@appsilon.com", role = "aut"),
    person("Appsilon Sp. z o.o.", , , "opensource@appsilon.com", role = "cph")
  )
Description: Enables instrumentation of 'Shiny' apps for tracking
    user session events such as input changes, browser type, and session
    duration.  These events can be sent to any of the available storage
    backends and analyzed using the included 'Shiny' app to gain insights
    about app usage and adoption.
License: LGPL-3
URL: https://appsilon.github.io/shiny.telemetry/,
        https://github.com/Appsilon/shiny.telemetry
BugReports: https://github.com/Appsilon/shiny.telemetry/issues
Imports: checkmate, digest, dplyr (>= 1.1.0), glue, htmltools, httr2,
        jsonlite, lifecycle, logger, lubridate, odbc, purrr, R6, rlang,
        RSQLite, shiny, stringr, tidyr
Suggests: box, config, DT, knitr, mongolite, plotly, plumber,
        RColorBrewer, RMariaDB, rmarkdown, RPostgres, RPostgreSQL,
        scales, semantic.dashboard (>= 0.1.1), shiny.semantic (>=
        0.2.0), shinyjs, testthat (>= 3.1.7), timevis, withr
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-26 11:47:21 UTC; averissimo
Author: André Veríssimo [aut, cre],
  Kamil Żyła [aut],
  Krystian Igras [aut],
  Recle Vibal [aut],
  Arun Kodati [aut],
  Wahaduzzaman Khan [aut],
  Appsilon Sp. z o.o. [cph]
Maintainer: André Veríssimo <opensource+andre@appsilon.com>
Repository: CRAN
Date/Publication: 2025-08-26 14:20:06 UTC
Built: R 4.6.0; ; 2026-04-26 21:34:48 UTC; unix
