# Generated by roxygen2: do not edit by hand

export(DataStorageLogFile)
export(DataStorageMSSQLServer)
export(DataStorageMariaDB)
export(DataStorageMongoDB)
export(DataStoragePlumber)
export(DataStoragePostgreSQL)
export(DataStorageSQLite)
export(Telemetry)
export(analytics_app)
export(build_id_from_secret)
export(build_token)
export(date_from_null)
export(date_to_null)
export(use_telemetry)
importFrom(dplyr,"%>%")
importFrom(rlang,"%||%")
importFrom(rlang,.data)
