# Instrumented app with Microsoft SQL Server backend

This example application uses MS SQL as a provider for data storage.

It is bundled with an example docker container provided by `docker-compose.yml`.
The database instance has to be running for the application and analytics dashboard to work.

### Requirements

The database needs to be created manually. Chunk below allows to create databse using the `sqlcmd` utility.

```
CREATE DATABASE shiny_telemetry
GO
```

The Microsoft ODBC 18 driver has to be installed in the system to use this example.

https://learn.microsoft.com/en-us/sql/connect/odbc/microsoft-odbc-driver-for-sql-server?view=sql-server-ver16&viewFallbackFrom=sql-server-ver18
