# Instrumented app with MongoDB backend

This example application uses MongoDB as a provider for data storage.

It is bundled with an example docker container provided by `docker-compose.yml`.
The MongoDB instance has to be running for the application and analytics dashboard to work.
