# Instrumented app with MariaDB backend

This example application uses MariaDB as a provider for data storage.

It is bundled with an example docker container provided by `docker-compose.yml`.
The MariaDB instance has to be running for the application and analytics dashboard to work.

_note:_ This should also suport a MySQL database.
