# Instrumented app with PostgreSQL backend

This example application uses PostgreSQL as a provider for data storage.

It is bundled with an example docker container provided by `docker-compose.yml`.
The PostgreSQL instance has to be running for the application and analytics dashboard to work.
